==> igniteui-react-16.16.2.tgz: package/esm2015/lib/TreeItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let TreeItem = /*@__PURE__*/ (() => {
    class TreeItem extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.j = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.b.d = this.j;
        }
        get a() {
            let ret_ = this.c.c("parent");
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.c.i("parent", value_);
        }
        get i() {
            let ret_ = this.c.c("level");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.c.i("level", value_);
        }
        get m() {
            let ret_ = this.c.c("label");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.c.i("label", value_);
        }
        get f() {
            let ret_ = this.c.c("expanded");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.c.i("expanded", value_);
        }
        get d() {
            let ret_ = this.c.c("active");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.i("active", value_);
        }
        get e() {
            let ret_ = this.c.c("disabled");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.c.i("disabled", value_);
        }
        get h() {
            let ret_ = this.c.c("selected");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.c.i("selected", value_);
        }
        get g() {
            let ret_ = this.c.c("loading");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.c.i("loading", value_);
        }
        get l() {
            let ret_ = this.c.c("value");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.c.i("value", value_);
        }
        p() {
            this.nativeElement.connectedCallback();
        }
        q() {
            this.nativeElement.disconnectedCallback();
        }
        s() {
            this.nativeElement.expandWithEvent();
        }
        o() {
            this.nativeElement.collapseWithEvent();
        }
        t() {
            this.nativeElement.toggle();
        }
        r() {
            this.nativeElement.expand();
        }
        n() {
            this.nativeElement.collapse();
        }
    }
    TreeItem.$t = /*@__PURE__*/ markType(TreeItem, 'TreeItem', BaseElement.$);
    return TreeItem;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/TreeItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let TreeItem = /*@__PURE__*/ (() => {
    class TreeItem extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.k = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.c.o = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.d.m("parent", (a) => new TreeItem());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.d.v("parent", value_);
        }
        get j() {
            let ret_ = this.d.n("level");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.d.v("level", value_);
        }
        get n() {
            let ret_ = this.d.n("label");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.d.v("label", value_);
        }
        get g() {
            let ret_ = this.d.n("expanded");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.v("expanded", value_);
        }
        get e() {
            let ret_ = this.d.n("active");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.v("active", value_);
        }
        get f() {
            let ret_ = this.d.n("disabled");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.d.v("disabled", value_);
        }
        get i() {
            let ret_ = this.d.n("selected");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.d.v("selected", value_);
        }
        get h() {
            let ret_ = this.d.n("loading");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.v("loading", value_);
        }
        get m() {
            let ret_ = this.d.n("value");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.d.v("value", value_);
        }
        get a() {
            let ret_ = this.d.m("path", (a) => new TreeItem());
            return ret_;
        }
        q() {
            this.nativeElement.connectedCallback();
        }
        r() {
            this.nativeElement.disconnectedCallback();
        }
        t() {
            this.nativeElement.expandWithEvent();
        }
        p() {
            this.nativeElement.collapseWithEvent();
        }
        v() {
            this.nativeElement.toggle();
        }
        s() {
            this.nativeElement.expand();
        }
        o() {
            this.nativeElement.collapse();
        }
    }
    TreeItem.$t = /*@__PURE__*/ markType(TreeItem, 'TreeItem', BaseElement.$);
    return TreeItem;
})();
